@@ -151,7 +151,9 @@ def adjust_colours_pvals(colours, pvals,triangles,mask=None):
     colours[verts_grey_out,:] = (1.5*colours[verts_grey_out] + np.array([0.86,0.86,0.86,1]))/2.5
     return colours
 
-def add_parcelation_colours(colours,parcel,triangles,labels=None,mask=None,filled=False):
+
+
+def add_parcellation_colours(colours,parcel,triangles,labels=None,mask=None,filled=False):
     """delineate regions"""
     if mask is not None:
         verts_masked = mask[triangles].any(axis=1)
@@ -323,7 +325,7 @@ def plot_surf(vertices, faces,overlay, rotate=[90,270], cmap='viridis', filename
         elif mask is not None:
             C = mask_colours(C,F,mask)
         if parcel is not None :
-            C = add_parcelation_colours(C,parcel,F,parcel_cmap,mask,filled=filled_parcels)
+            C = add_parcellation_colours(C,parcel,F,parcel_cmap,mask,filled=filled_parcels)
             
         #adjust intensity based on light source here
         C[:,0] *= intensity
